@@ -3,7 +3,6 @@
 
 :author: Pawel Chomicki
 """
-
 import os
 import re
 
@@ -59,6 +58,8 @@ def pytest_runtest_logreport(self, report):
     res = self.config.hook.pytest_report_teststatus(report=report, config=self.config)
     cat, letter, word = res
     self.stats.setdefault(cat, []).append(report)
+    if _is_ignored(report.nodeid, self.config.getini('spec_ignore').split(',')):
+        return
     if not letter and not word:
         return
     if not _is_nodeid_has_test(report.nodeid):
@@ -80,9 +81,19 @@ def pytest_runtest_logreport(self, report):
 
     if not isinstance(word, tuple):
         test_name = _get_test_name(report.nodeid)
+        docstring_summary = getattr(report, 'docstring_summary', '')
+        docstring_summary = docstring_summary if docstring_summary else test_name
         markup, test_status = _format_results(report, self.config)
-        depth = len(self.current_scopes)
-        _print_test_result(self, test_name, test_status, markup, depth)
+        depth = len(self.current_scopes) or 1
+        _print_test_result(self, test_name, docstring_summary, test_status, markup, depth)
+
+
+def _is_ignored(nodeid, ignore_strings):
+    if ignore_strings:
+        for ignore_string in ignore_strings:
+            if ignore_string and ignore_string in nodeid:
+                return True
+    return False
 
 
 def _is_nodeid_has_test(nodeid):
@@ -188,11 +199,11 @@ def _format_results(report, config):
         return {'yellow': True}, skipped_indicator
 
 
-def _print_test_result(self, test_name, test_status, markup, depth):
+def _print_test_result(self, test_name, docstring_summary, test_status, markup, depth):
     indent = self.config.getini('spec_indent')
     self._tw.line()
     self._tw.write(
         indent * depth + self.config.getini('spec_test_format').format(
-            result=test_status, name=test_name
+            result=test_status, name=test_name, docstring_summary=docstring_summary
         ), **markup
     )
