@@ -3,6 +3,8 @@
 
 :author: Pawel Chomicki
 """
+import pytest
+
 from .replacer import logstart_replacer, report_replacer, modifyitems_replacer
 
 
@@ -38,7 +40,7 @@ def pytest_addoption(parser):
     )
     parser.addini(
         'spec_skipped_indicator',
-        default='?',
+        default='»',
         help='The indicator displayed when a test is skipped'
     )
     parser.addini(
@@ -46,6 +48,11 @@ def pytest_addoption(parser):
         default='  ',
         help='The string used for indentation in the spec output'
     )
+    parser.addini(
+        'spec_ignore',
+        default='',
+        help='The comma-separated list of strings used to ignore tests in the spec output e.g. FLAKE8'
+    )
 
 
 def pytest_configure(config):
@@ -56,3 +63,12 @@ def pytest_configure(config):
         _pytest.terminal.TerminalReporter.pytest_runtest_logreport = report_replacer
         _pytest.terminal.TerminalReporter.pytest_collection_modifyitems = modifyitems_replacer
         six.moves.reload_module(_pytest)
+
+
+@pytest.mark.hookwrapper
+def pytest_runtest_makereport(item, call):
+    outcome = yield
+    report = outcome.get_result()
+    node = getattr(item, 'obj', None)
+    if node and item.obj.__doc__:
+        report.docstring_summary = str(item.obj.__doc__).lstrip().split("\n")[0].strip()
