@@ -25,6 +25,14 @@ class TestFormats(unittest.TestCase):
         """Shows custom message from docstring summary"""
         assert SomeClass().some_method(None) is None
 
+    def test_with_multiline_docstring(self):
+        """
+        Shows custom message from docstring summary
+
+        And doesn't show additional info.
+        """
+        assert SomeClass().some_method(None) is None
+
 
 if __name__ == '__main__':
     unittest.main()
